@@ -21,32 +21,66 @@ package Babble::Cache::Storable;
 use strict;
 use Storable;
 
-sub cache_load ($$) {
-	my ($self, $fn, $cachedb) = @_;
+use Babble::Cache::Class::Hash;
+use vars qw(@ISA);
 
-	$$cachedb = Storable::retrieve $fn;
-}
-
-sub cache_dump ($$) {
-	my ($self, $fn, $cachedb) = @_;
-
-	Storable::store $$cachedb, $fn;
-}
+@ISA = qw(Babble::Cache::Class::Hash);
 
 =pod
 
 =head1 NAME
 
-Babble::Cache::Storable - Storable data storage for Babble::Cache
+Babble::Cache::Storable - Storable-based cache for Babble
 
 =head1 DESCRIPTION
 
-This module implements a storage format for B<Babble::Cache> that uses
-B<Storable> to store and retrieve the cache.
+This module implements a cache for B<Babble> that uses B<Storable> to
+store and retrieve the cache. The cache itself is stored in memory in
+a hash (thus, this class is a subclass of
+B<Babble::Cache::Class::Hash>).
 
 The main advantage is speed, but the stored cache is not human
 readable.
 
+=head1 METHODS
+
+=over 4
+
+=item load ()
+
+Load the cache stored in B<Storable> format from the file
+specified during object creation.
+
+=cut
+
+sub load () {
+	my $self = shift;
+
+	return 1 unless ($self->{-cache_fn} && -e $self->{-cache_fn});
+	$self->{cachedb} = Storable::retrieve $self->{-cache_fn};
+}
+
+=pod
+
+=item dump ()
+
+Save the cache in B<Storable> format to the file specified during
+object creation.
+
+=cut
+
+sub dump () {
+	my $self = shift;
+
+	return unless $self->{-cache_fn};
+
+	Storable::store $self->{cachedb}, $self->{-cache_fn};
+}
+
+=pod
+
+=back
+
 =head1 AUTHOR
 
 Gergely Nagy, algernon@bonehunter.rulez.org
@@ -55,7 +89,7 @@ Bugs should be reported at L<http://bugs.bonehunter.rulez.org/babble>.
 
 =head1 SEE ALSO
 
-Storable(3pm), Babble(3pm), Babble::Cache(3pm)
+Storable, Babble, Babble::Cache, Babble::Cache::Class::Hash
 
 =cut
 
