@@ -21,6 +21,7 @@ package Babble::DataSource::FlatFile;
 use strict;
 use Carp;
 
+use Babble::Encode;
 use Babble::Document;
 use Babble::Document::Collection;
 use Babble::DataSource;
@@ -29,8 +30,8 @@ use File::Find;
 use File::stat;
 use File::Basename;
 use Date::Manip;
+use User::pwent;
 
-use Exporter ();
 use vars qw(@ISA);
 @ISA = qw(Babble::DataSource);
 
@@ -76,19 +77,19 @@ my $permalink_blosxom = sub {
 
 =over 4
 
-=item I<new>(B<%params>)
+=item new (%params)
 
 This method creates a new object. The recognised arguments are
-I<-location>, which specifies the directory where documents should be
-collected from; I<-extension>, a regexp that will be used to find out
+B<-location>, which specifies the directory where documents should be
+collected from; B<-extension>, a regexp that will be used to find out
 which files are documents, and which are not (defaults to C<\.txt>);
-I<-permalink_base>, the base URL for the collection (used by the
-permanent link generator, see later); and I<-permalink_gen>, a code
+B<-permalink_base>, the base URL for the collection (used by the
+permanent link generator, see later); and B<-permalink_gen>, a code
 reference that is used to generate links to documents.
 
-The method specified in I<-permalink_gen> takes four arguments:
-I<base>, I<file>, I<date> and I<ext>. All of them are string scalar
-references. Base is what we specified using I<-permalink_base>, file
+The method specified in B<-permalink_gen> takes four arguments:
+B<base>, B<file>, B<date> and B<ext>. All of them are string scalar
+references. Base is what we specified using B<-permalink_base>, file
 is the full path to the filename we're currently operating on, date is
 its submission date, and ext is its extension.
 
@@ -108,41 +109,40 @@ sub new {
 
 =pod
 
-=item I<collect>()
+=item collect ()
 
 This function finds all the files in the data directory (recursively)
-which have the specified extension, and makes a Babble::Document out
-of them. The title is the first line of the file, the date is its
+which have the specified extension, and makes a B<Babble::Document>
+out of them. The title is the first line of the file, the date is its
 modification time, subject is the subdirectory under which it was
 found (or main, if it was in the top-level directory), author is the
 user owning the file, content is the file content, save the first
 line.
 
 It's id property contains a pointer to the entry (eg, to one's
-weblog). This is generated by the I<$source-E<gt>{permalink_gen}>
+weblog). This is generated by the B<$source-E<gt>{permalink_gen}>
 function, explained above.
 
 For the Babble::Document::Collection object to return, some
 information will be gathered from the Babble object which calls this
 method, or from the parameters passed to us. Namely, the
-I<meta_title>, I<meta_desc>, I<meta_link>, I<meta_owner>,
-I<meta_owner_email>, I<meta_subject> and I<meta_feed_link> keys will
-be used, if present.
+B<meta_title>, B<meta_desc>, B<meta_link>, B<meta_owner>,
+B<meta_owner_email>, B<meta_subject>, B<meta_image> and
+B<meta_feed_link> keys will be used, if present.
 
 =cut
 
-sub collect($) {
+sub collect ($) {
 	my ($self, $babble) = @_;
 	my @files = ();
 	my $collection;
 	my %args;
 
 	foreach ("meta_title", "meta_desc", "meta_link", "meta_owner_email",
-		 "meta_subject", "meta_feed_link", "meta_owner") {
-		$args{$_} = $$babble->{Params}->{$_};
-
-		$args{$_} = $self->{$_} if (defined $self->{$_});
-		$args{$_} = "" if (!$args{$_});
+		 "meta_subject", "meta_feed_link", "meta_owner",
+		 "meta_image") {
+		$args{$_} = $self->{$_} || $$babble->{Params}->{$_} || "";
+		$args{$_} = to_utf8 ($args{$_});
 	}
 
 	find ({wanted => sub {
@@ -158,8 +158,9 @@ sub collect($) {
 		content => $args{meta_desc},
 		date => ParseDate ("today"),
 		subject => $args{meta_subject},
-		name => $self->{-id} || $args{meta_owner} ||
+		name => to_utf8 ($self->{-id}) || $args{meta_owner} ||
 			$args{meta_owner_email} || $args{meta_title},
+		image => $args{meta_image},
 	);
 
 	foreach my $file (@files) {
@@ -184,12 +185,13 @@ sub collect($) {
 						 \$self->{-extension});
 
 		$doc = Babble::Document->new (
-			title => $title,
+			title => to_utf8 ($title),
 			id => $link,
-			content => join ("", @content),
-			subject => $subject,
+			content => to_utf8 (join ("", @content)),
+			subject => to_utf8 ($subject),
 			date => ParseDate ($date),
-			author => getpwuid (stat ($file)->uid),
+			author => to_utf8
+				(getpwuid (stat ($file)->uid)->name),
 		);
 
 		push (@{$collection->{documents}}, $doc);
@@ -210,8 +212,8 @@ Bugs should be reported at L<http://bugs.bonehunter.rulez.org/babble>.
 
 =head1 SEE ALSO
 
-Babble::Document, Babble::Document::Collection,
-Babble::DataSource
+Babble::Document(3pm), Babble::Document::Collection(3pm),
+Babble::DataSource(3pm)
 
 =cut
 
